==> alicevision_3.2.0+repack.orig.tar.xz: AliceVision-3.2.0/COPYING.md <==
## AliceVision License

AliceVision is licensed under the [MPL2 license](LICENSE-MPL2.md).

[CMPMVS](http://people.ciirc.cvut.cz/~pajdla/) has been the first step to build the AliceVision MVS pipeline and was CTU proprietary solution before being part of AliceVision.  
[openMVG](https://github.com/openMVG/openMVG) has been the first step to build the AliceVision SfM pipeline and was released under [MPLv2](LICENSE-MPL2.md).  
[libmv](https://github.com/libmv/libmv) has been an important source of inspiration for the design and part of the code of the "multiview" and "robustEstimation"
modules are based on the libmv code released under MIT, see [LICENSE-MIT-libmv.md](LICENSE-MIT-libmv.md).


It also contains one file with different license:

*   __kvld__  
    [src/aliceVision/matching/kvld](src/aliceVision/matching/kvld)  
    Copyright (C) 2011-12 Zhe Liu and Pierre Moulon.  
    This file was first released under BSD-2-Clause license, see [LICENSE-BSD-2-Clause](http://opensource.org/licenses/BSD-2-Clause).


## Third parties licenses

This program is based on works distributed under the terms of another license(s) and other copyright notice(s).

*   __Alembic__ (optional)  
    [http://www.alembic.io](http://www.alembic.io)  
    Copyright 2009-2015 Lucasfilm Entertainment Company Ltd. or Lucasfilm Ltd.  
    Copyright 2009-2015 Sony Pictures Imageworks Inc.  
    Distributed under the [BSD-3-Clause](https://github.com/alembic/alembic/blob/master/LICENSE.txt).

*   __Boost__  
    [http://www.boost.org](http://www.boost.org)  
    Distributed under the [Boost Software License](http://www.boost.org/users/license.html).

*   __CCTag__ (optional)  
    [https://github.com/alicevision/CCTag](https://github.com/alicevision/CCTag)  
    Copyright 2016, Simula Research Laboratory  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __Ceres-Solver__  
    [http://ceres-solver.org](http://ceres-solver.org)  
    Copyright 2015 Google Inc. All rights reserved.  
    Distributed under the [New BSD licence](http://ceres-solver.org/license.html).

*   __Clp__  
    Copyright (C) 2002, 2003 International Business Machines Corporation  
    and others.  All Rights Reserved.  
    Distributed under the terms of the Eclipse Public License (EPL).

*   __CoinUtils__  
    Copyright (C) 1987, 2009 International Business Machines Corporation  
    and others.  All Rights Reserved.  
    Distributed under the terms of the Eclipse Public License (EPL).

*   __CUDA__ (required for the depth map computation)  
    See [License](https://docs.nvidia.com/cuda/eula/index.html#license-driver).

*   __cxsparse__  (optional)  
    Copyright (c) 2006-2012, Timothy A. Davis.  
    Distributed under the [GNU LGPL license](http://opensource.org/licenses/lgpl-license).

*   __Eigen__  
    [http://eigen.tuxfamily.org](http://eigen.tuxfamily.org)  
    Copyright (c) Eigen authors.  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).  
    Compiled with EIGEN_MPL2_ONLY to ensure MPL2 compatible code.

*   __Expat__  
    https://libexpat.github.io/
    Copyright (c) 1998-2000 Thai Open Source Software Center Ltd and Clark Cooper
    Copyright (c) 2001-2022 Expat maintainers
    Distributed under the MIT/X Consortium license

*   __Flann__  
    [https://www.cs.ubc.ca/research/flann](https://www.cs.ubc.ca/research/flann)  
    Copyright (c) 2008-2011  Marius Muja (mariusm@cs.ubc.ca). All rights reserved.  
    Copyright (c) 2008-2011  David G. Lowe (lowe@cs.ubc.ca). All rights reserved.  
    Distributed under the [BSD License](http://www.opensource.org/licenses/bsd-license.php).

*   __Geogram__  
    [http://alice.loria.fr/software/geogram/doc/html/index.html](http://alice.loria.fr/software/geogram/doc/html/index.html)  
    Copyright (c) 2012-2014 Bruno Levy. All rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __Histogram__  
    Copyright (c) Jansson Consulting & Pierre Moulon.  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __HtmlDoc__  
    Copyright (c) Pierre Moulon.  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __Lemon__  
    [http://lemon.cs.elte.hu/trac/lemon](http://lemon.cs.elte.hu/trac/lemon)  
    Copyright (c) Lemon authors.  
    Distributed under the [Boost License 1.0](http://www.boost.org/LICENSE_1_0.txt).

*   __MeshSDFilter__  
    [https://github.com/bldeng/MeshSDFilter](https://github.com/bldeng/MeshSDFilter)  
    Copyright (c) 2017, Bailin Deng. All rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __Nanoflann__  
    [https://github.com/jlblancoc/nanoflann](https://github.com/jlblancoc/nanoflann)  
    Copyright 2008-2009  Marius Muja (mariusm@cs.ubc.ca). All rights reserved.  
    Copyright 2008-2009  David G. Lowe (lowe@cs.ubc.ca). All rights reserved.  
    Copyright 2011 Jose L. Blanco (joseluisblancoc@gmail.com). All rights reserved.  
    Distributed under the [BSD License](http://www.opensource.org/licenses/bsd-license.php).

*   __OpenCV__ (optional)  
    [https://opencv.org](https://opencv.org)  
    Copyright (C) 2000-2016, Intel Corporation, all rights reserved.  
    Copyright (C) 2009-2011, Willow Garage Inc., all rights reserved.  
    Copyright (C) 2009-2016, NVIDIA Corporation, all rights reserved.  
    Copyright (C) 2010-2013, Advanced Micro Devices, Inc., all rights reserved.  
    Copyright (C) 2015-2016, OpenCV Foundation, all rights reserved.  
    Copyright (C) 2015-2016, Itseez Inc., all rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __OpenEXR__ (required by OpenImageIO and used in the pipeline)  
    [http://www.openexr.com](http://www.openexr.com)  
    Copyright (c) 2002, Industrial Light & Magic, a division of Lucas Digital Ltd. LLC  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __OpenGV__ (optional)  
    [https://laurentkneip.github.io/opengv](https://laurentkneip.github.io/opengv)  
    Copyright (c) 2013 Laurent Kneip, The Australian National University ANU. All rights reserved  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __OpenImageIO__  
    [https://openimageio.org](https://openimageio.org)  
    Copyright 2008-2016 Larry Gritz et al.  
    Distributed under the [BSD-3-Clause](https://github.com/OpenImageIO/oiio/blob/master/LICENSE).

*   __OpenMesh__ (required by MeshSDFilter)  
    [http://openmesh.org](http://openmesh.org)  
    Copyright (c) 2001-2015, RWTH-Aachen University.  
    Department of Computer Graphics and Multimedia. All rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __Osi__  
    Copyright (C) 2000 International Business Machines Corporation  
    and others.  All Rights Reserved.  
    Distributed under the terms of the Eclipse Public License (EPL).

*   __PopSift__ (optional)  
    [https://github.com/alicevision/popsift](https://github.com/alicevision/popsift)  
    Copyright 2016, Simula Research Laboratory  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).
    SIFT was patented in the United States from 1999-03-08 to 2020-03-28. See the [patent link](https://patents.google.com/patent/US6711293B1/en) for more information.
*   __vectorGraphics__  
    Copyright (c) Pierre Moulon  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __vlfeat__  
    [http://www.vlfeat.org](http://www.vlfeat.org)  
    Copyright (C) 2007-12 Andrea Vedaldi and Brian Fulkerson. All rights reserved.  
    Distributed under the [BSD License](http://www.opensource.org/licenses/bsd-license.php).
    SIFT was patented in the United States from 1999-03-08 to 2020-03-28. See the [patent link](https://patents.google.com/patent/US6711293B1/en) for more information.

*   __zlib__  (optional)  
    [https://zlib.net](https://zlib.net)  
    Copyright (C) 1995-2005 Jean-loup Gailly  
    Distributed under the [zlib license](http://opensource.org/licenses/Zlib).

==> alicevision_3.3.1+repack.orig.tar.xz: AliceVision-3.3.1/COPYING.md <==
## AliceVision License

AliceVision is licensed under the [MPL2 license](LICENSE-MPL2.md).

[CMPMVS](http://people.ciirc.cvut.cz/~pajdla/) has been the first step to build the AliceVision MVS pipeline and was CTU proprietary solution before being part of AliceVision.  
[openMVG](https://github.com/openMVG/openMVG) has been the first step to build the AliceVision SfM pipeline and was released under [MPLv2](LICENSE-MPL2.md).  
[libmv](https://github.com/libmv/libmv) has been an important source of inspiration for the design and part of the code of the "multiview" and "robustEstimation"
modules are based on the libmv code released under MIT, see [LICENSE-MIT-libmv.md](LICENSE-MIT-libmv.md).


It also contains one file with different license:

*   __kvld__  
    [src/aliceVision/matching/kvld](src/aliceVision/matching/kvld)  
    Copyright (C) 2011-12 Zhe Liu and Pierre Moulon.  
    This file was first released under BSD-2-Clause license, see [LICENSE-BSD-2-Clause](http://opensource.org/licenses/BSD-2-Clause).


## Third parties licenses

This program is based on works distributed under the terms of another license(s) and other copyright notice(s).

*   __Alembic__ (optional)  
    [http://www.alembic.io](http://www.alembic.io)  
    Copyright 2009-2015 Lucasfilm Entertainment Company Ltd. or Lucasfilm Ltd.  
    Copyright 2009-2015 Sony Pictures Imageworks Inc.  
    Distributed under the [BSD-3-Clause](https://github.com/alembic/alembic/blob/master/LICENSE.txt).

*   __Boost__  
    [http://www.boost.org](http://www.boost.org)  
    Distributed under the [Boost Software License](http://www.boost.org/users/license.html).

*   __CCTag__ (optional)  
    [https://github.com/alicevision/CCTag](https://github.com/alicevision/CCTag)  
    Copyright 2016, Simula Research Laboratory  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __Ceres-Solver__  
    [http://ceres-solver.org](http://ceres-solver.org)  
    Copyright 2015 Google Inc. All rights reserved.  
    Distributed under the [New BSD licence](http://ceres-solver.org/license.html).

*   __Clp__  
    Copyright (C) 2002, 2003 International Business Machines Corporation  
    and others.  All Rights Reserved.  
    Distributed under the terms of the Eclipse Public License (EPL).

*   __CoinUtils__  
    Copyright (C) 1987, 2009 International Business Machines Corporation  
    and others.  All Rights Reserved.  
    Distributed under the terms of the Eclipse Public License (EPL).

*   __CUDA__ (required for the depth map computation)  
    See [License](https://docs.nvidia.com/cuda/eula/index.html#license-driver).

*   __cxsparse__  (optional)  
    Copyright (c) 2006-2012, Timothy A. Davis.  
    Distributed under the [GNU LGPL license](http://opensource.org/licenses/lgpl-license).

*   __Eigen__  
    [http://eigen.tuxfamily.org](http://eigen.tuxfamily.org)  
    Copyright (c) Eigen authors.  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).  
    Compiled with EIGEN_MPL2_ONLY to ensure MPL2 compatible code.

*   __Expat__  
    https://libexpat.github.io/
    Copyright (c) 1998-2000 Thai Open Source Software Center Ltd and Clark Cooper
    Copyright (c) 2001-2022 Expat maintainers
    Distributed under the MIT/X Consortium license

*   __Flann__  
    [https://www.cs.ubc.ca/research/flann](https://www.cs.ubc.ca/research/flann)  
    Copyright (c) 2008-2011  Marius Muja (mariusm@cs.ubc.ca). All rights reserved.  
    Copyright (c) 2008-2011  David G. Lowe (lowe@cs.ubc.ca). All rights reserved.  
    Distributed under the [BSD License](http://www.opensource.org/licenses/bsd-license.php).

*   __Geogram__  
    [http://alice.loria.fr/software/geogram/doc/html/index.html](http://alice.loria.fr/software/geogram/doc/html/index.html)  
    Copyright (c) 2012-2014 Bruno Levy. All rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __Histogram__  
    Copyright (c) Jansson Consulting & Pierre Moulon.  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __HtmlDoc__  
    Copyright (c) Pierre Moulon.  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __Lemon__  
    [http://lemon.cs.elte.hu/trac/lemon](http://lemon.cs.elte.hu/trac/lemon)  
    Copyright (c) Lemon authors.  
    Distributed under the [Boost License 1.0](http://www.boost.org/LICENSE_1_0.txt).

*   __libE57Format__  
    [https://github.com/asmaloney/libE57Format](https://github.com/asmaloney/libE57Format)  
    Copyright (c) libE57Format authors.  
    Distributed under the [BSL-1.0 license](https://opensource.org/licenses/BSL-1.0).   

*   __MeshSDFilter__  
    [https://github.com/bldeng/MeshSDFilter](https://github.com/bldeng/MeshSDFilter)  
    Copyright (c) 2017, Bailin Deng. All rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __Nanoflann__  
    [https://github.com/jlblancoc/nanoflann](https://github.com/jlblancoc/nanoflann)  
    Copyright 2008-2009  Marius Muja (mariusm@cs.ubc.ca). All rights reserved.  
    Copyright 2008-2009  David G. Lowe (lowe@cs.ubc.ca). All rights reserved.  
    Copyright 2011 Jose L. Blanco (joseluisblancoc@gmail.com). All rights reserved.  
    Distributed under the [BSD License](http://www.opensource.org/licenses/bsd-license.php).

*   __OpenCV__ (optional)  
    [https://opencv.org](https://opencv.org)  
    Copyright (C) 2000-2016, Intel Corporation, all rights reserved.  
    Copyright (C) 2009-2011, Willow Garage Inc., all rights reserved.  
    Copyright (C) 2009-2016, NVIDIA Corporation, all rights reserved.  
    Copyright (C) 2010-2013, Advanced Micro Devices, Inc., all rights reserved.  
    Copyright (C) 2015-2016, OpenCV Foundation, all rights reserved.  
    Copyright (C) 2015-2016, Itseez Inc., all rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __OpenEXR__ (required by OpenImageIO and used in the pipeline)  
    [http://www.openexr.com](http://www.openexr.com)  
    Copyright (c) 2002, Industrial Light & Magic, a division of Lucas Digital Ltd. LLC  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __OpenImageIO__  
    [https://openimageio.org](https://openimageio.org)  
    Copyright 2008-2016 Larry Gritz et al.  
    Distributed under the [BSD-3-Clause](https://github.com/OpenImageIO/oiio/blob/master/LICENSE).

*   __OpenMesh__ (required by MeshSDFilter)  
    [http://openmesh.org](http://openmesh.org)  
    Copyright (c) 2001-2015, RWTH-Aachen University.  
    Department of Computer Graphics and Multimedia. All rights reserved.  
    Distributed under the [BSD-3-Clause](https://opensource.org/licenses/BSD-3-Clause)

*   __Osi__  
    Copyright (C) 2000 International Business Machines Corporation  
    and others.  All Rights Reserved.  
    Distributed under the terms of the Eclipse Public License (EPL).

*   __PopSift__ (optional)  
    [https://github.com/alicevision/popsift](https://github.com/alicevision/popsift)  
    Copyright 2016, Simula Research Laboratory  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).
    SIFT was patented in the United States from 1999-03-08 to 2020-03-28. See the [patent link](https://patents.google.com/patent/US6711293B1/en) for more information.
*   __vectorGraphics__  
    Copyright (c) Pierre Moulon  
    Distributed under the [MPL2 license](http://opensource.org/licenses/MPL-2.0).

*   __vlfeat__  
    [http://www.vlfeat.org](http://www.vlfeat.org)  
    Copyright (C) 2007-12 Andrea Vedaldi and Brian Fulkerson. All rights reserved.  
    Distributed under the [BSD License](http://www.opensource.org/licenses/bsd-license.php).
    SIFT was patented in the United States from 1999-03-08 to 2020-03-28. See the [patent link](https://patents.google.com/patent/US6711293B1/en) for more information.

*   __zlib__  (optional)  
    [https://zlib.net](https://zlib.net)  
    Copyright (C) 1995-2005 Jean-loup Gailly  
    Distributed under the [zlib license](http://opensource.org/licenses/Zlib).
